import { useEffect } from 'react';
import hookForm from 'hook-easy-form';
import { useHistory } from 'react-router-dom';
import { useDispatch, useSelector } from 'react-redux';

import { runAuth } from 'store/auth/actions';
import Input from 'components/inputs/text-input/text-input';

import classes from './auth.module.scss';

const form = [
  {
    name: 'email',
    value: '',
    required: true,
    options: {
      type: 'email',
      label: 'Your email'
    }
  },
  {
    name: 'password',
    value: '',
    required: true,
    options: {
      type: 'password',
      label: 'Your password'
    },
    validate: {
      maxLength: (v) => (v.trim().length < 6 ? 'Invalid' : ''),
    },
  },
]

const Auth = () => {
  const dispatch = useDispatch();
  const history = useHistory();

  const user = useSelector((s) => s.auth.user)
  console.log('user', user);
  useEffect(() => {
    if (user) history.push('/');
  }, [user, history]);

  const { formArray, updateEvent, valid, disabled, submitEvent } = hookForm({ initialForm: form })

  const submit = submitEvent((v) => dispatch(runAuth(v)));

  return (
    <div className={classes.container}>
      <form onSubmit={submit} className={classes.form}>
        {formArray.map(el => (
          <div className={classes.form} key={el.name}>
            <Input
              name={el.name}
              label={el.options.label}
              type={el.options.type}
              onChange={updateEvent} />
          </div>
        ))}
        <button type="submit" disabled={disabled || !valid}>Submit</button>
      </form>
    </div>
  )
}

export default Auth;