import axios from 'axios';

import { getToken } from 'utils/local-storage-actions';

const instance = axios.create({
  baseURL: 'http://localhost:8000',
  headers: { 'Content-Type': 'application/json' },
});

instance.interceptors.request.use(function (config) {
  console.log('config', config);
  const token = getToken();

  config.headers.Authorization = `Bearer ${token}`
  config.headers['Accepted-language'] = 'ru';

  // Do something before request is sent
  return config;
}, function (error) {
  // Do something with request error
  return Promise.reject(error);
});

// Add a response interceptor
instance.interceptors.response.use(function (response) {
  // Any status code that lie within the range of 2xx cause this function to trigger
  // Do something with response data
  return response;
}, function (error) {
  // Any status codes that falls outside the range of 2xx cause this function to trigger
  // Do something with response error
  return Promise.reject(error);
});


export const AxiosInstance = ({ url, method = 'GET', params, data }) => instance({ url, method, params, data });